/* This file was generated by syncqt. */
#ifndef QT_QTGSTREAMERMEDIAPLUGINIMPL_VERSION_H
#define QT_QTGSTREAMERMEDIAPLUGINIMPL_VERSION_H

#define QTGSTREAMERMEDIAPLUGINIMPL_VERSION_STR "6.9.1"

#define QTGSTREAMERMEDIAPLUGINIMPL_VERSION 0x060901

#endif // QT_QTGSTREAMERMEDIAPLUGINIMPL_VERSION_H
